@@ -858,8 +858,10 @@ start_process (struct ServiceList *sl,
      * of ''-quoted strings, escaping should be considered. */
     if (NULL != options)
       options = GNUNET_CONFIGURATION_expand_dollar (cfg, options);
-    sl->proc = GNUNET_OS_start_process_s (sl->pipe_control,
-                                          GNUNET_OS_INHERIT_STD_OUT_AND_ERR,
+    sl->proc = GNUNET_OS_start_process_s (sl->pipe_control
+                                          ? GNUNET_OS_INHERIT_STD_OUT_AND_ERR
+                                          | GNUNET_OS_USE_PIPE_CONTROL
+                                          : GNUNET_OS_INHERIT_STD_OUT_AND_ERR,
                                           lsocks,
                                           loprefix,
                                           quotedbinary,
@@ -880,7 +882,11 @@ start_process (struct ServiceList *sl,
     if (GNUNET_YES == use_debug)
     {
       if (NULL == sl->config)
-        sl->proc = GNUNET_OS_start_process_s (sl->pipe_control,
+        sl->proc = GNUNET_OS_start_process_s (sl->pipe_control
+                                              ?
+                                              GNUNET_OS_INHERIT_STD_OUT_AND_ERR
+                                              | GNUNET_OS_USE_PIPE_CONTROL
+                                              :
                                               GNUNET_OS_INHERIT_STD_OUT_AND_ERR,
                                               lsocks,
                                               loprefix,
@@ -890,7 +896,11 @@ start_process (struct ServiceList *sl,
                                               options,
                                               NULL);
       else
-        sl->proc = GNUNET_OS_start_process_s (sl->pipe_control,
+        sl->proc = GNUNET_OS_start_process_s (sl->pipe_control
+                                              ?
+                                              GNUNET_OS_INHERIT_STD_OUT_AND_ERR
+                                              | GNUNET_OS_USE_PIPE_CONTROL
+                                              :
                                               GNUNET_OS_INHERIT_STD_OUT_AND_ERR,
                                               lsocks,
                                               loprefix,
@@ -905,7 +915,11 @@ start_process (struct ServiceList *sl,
     else
     {
       if (NULL == sl->config)
-        sl->proc = GNUNET_OS_start_process_s (sl->pipe_control,
+        sl->proc = GNUNET_OS_start_process_s (sl->pipe_control
+                                              ?
+                                              GNUNET_OS_INHERIT_STD_OUT_AND_ERR
+                                              | GNUNET_OS_USE_PIPE_CONTROL
+                                              :
                                               GNUNET_OS_INHERIT_STD_OUT_AND_ERR,
                                               lsocks,
                                               loprefix,
@@ -913,7 +927,11 @@ start_process (struct ServiceList *sl,
                                               options,
                                               NULL);
       else
-        sl->proc = GNUNET_OS_start_process_s (sl->pipe_control,
+        sl->proc = GNUNET_OS_start_process_s (sl->pipe_control
+                                              ?
+                                              GNUNET_OS_INHERIT_STD_OUT_AND_ERR
+                                              | GNUNET_OS_USE_PIPE_CONTROL
+                                              :
                                               GNUNET_OS_INHERIT_STD_OUT_AND_ERR,
                                               lsocks,
                                               loprefix,
@@ -2152,7 +2170,7 @@ main (int argc, char *const *argv)
     GNUNET_MQ_handler_end ()
   };
 
-  sigpipe = GNUNET_DISK_pipe (GNUNET_NO, GNUNET_NO, GNUNET_NO, GNUNET_NO);
+  sigpipe = GNUNET_DISK_pipe (GNUNET_DISK_PF_NONE);
   GNUNET_assert (NULL != sigpipe);
   shc_chld =
     GNUNET_SIGNAL_handler_install (GNUNET_SIGCHLD,
