@@ -245,7 +245,7 @@ GCP_2s (const struct CadetPeer *cp)
   char *ret;
 
   if ((NULL == cp) ||
-      (0 == GNUNET_is_zero (&cp->pid.public_key)))
+      (GNUNET_YES == GNUNET_is_zero (&cp->pid.public_key)))
     return "NULL";
 
   ret = GNUNET_CRYPTO_eddsa_public_key_to_string (&cp->pid.public_key);
@@ -1552,6 +1552,7 @@ GCP_send_ooo (struct CadetPeer *cp,
                   env);
 }
 
+
 /**
  * Checking if a monotime value is newer than the last monotime value received from a peer. If the time value is newer it will be stored at the peer.
  *
@@ -1574,6 +1575,7 @@ GCP_check_and_update_monotime (struct CadetPeer *peer,
   return GNUNET_NO;
 }
 
+
 /**
  * Checking the signature for a monotime of a GNUNET_CADET_ConnectionCreateMessage.
  *
