@@ -189,7 +189,7 @@ copy_buffer (void *ptr, size_t size, size_t nmemb, void *ctx)
 }
 
 
-static int
+static enum MHD_Result
 mhd_ahc (void *cls,
          struct MHD_Connection *connection,
          const char *url,
@@ -528,8 +528,6 @@ run (void *cls,
 int
 main (int argc, char *const *argv)
 {
-  char *tmp_argv;
-
   struct GNUNET_GETOPT_CommandLineOption options[] = {
     GNUNET_GETOPT_option_uint16 ('p',
                                  "port",
@@ -559,7 +557,7 @@ main (int argc, char *const *argv)
   }
   if (GNUNET_OK !=
       GNUNET_STRINGS_get_utf8_args (argc, argv,
-                                    &argc, &tmp_argv))
+                                    &argc, &argv))
     return 2;
   GNUNET_log_setup ("gnunet-gns-proxy-test",
                     "WARNING",
@@ -570,7 +568,7 @@ main (int argc, char *const *argv)
                                        options,
                                        &run, NULL))
     return 1;
-  GNUNET_free (tmp_argv);
+  GNUNET_free_nz ((void*) argv);
   return global_ret;
 }
 
