@@ -1,28 +1,35 @@
 /*
       This file is part of GNUnet
-      (C) 2008--2013 Christian Grothoff (and other contributing authors)
+      Copyright (C) 2008--2013 GNUnet e.V.
 
-      GNUnet is free software; you can redistribute it and/or modify
-      it under the terms of the GNU General Public License as published
-      by the Free Software Foundation; either version 3, or (at your
-      option) any later version.
+      GNUnet is free software: you can redistribute it and/or modify it
+      under the terms of the GNU Affero General Public License as published
+      by the Free Software Foundation, either version 3 of the License,
+      or (at your option) any later version.
 
       GNUnet is distributed in the hope that it will be useful, but
       WITHOUT ANY WARRANTY; without even the implied warranty of
       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-      General Public License for more details.
+      Affero General Public License for more details.
 
-      You should have received a copy of the GNU General Public License
-      along with GNUnet; see the file COPYING.  If not, write to the
-      Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-      Boston, MA 02111-1307, USA.
+      You should have received a copy of the GNU Affero General Public License
+      along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+     SPDX-License-Identifier: AGPL3.0-or-later
  */
 
 /**
- * @file include/gnunet_testbed_service.h
- * @brief API for writing tests and creating large-scale
- *        emulation testbeds for GNUnet.
  * @author Christian Grothoff
+ *
+ * @file
+ * API for writing tests and creating large-scale emulation testbeds for GNUnet.
+ *
+ * @defgroup testbed  Testbed service
+ * Writing tests and creating large-scale emulation testbeds for GNUnet.
+ *
+ * @see [Documentation](https://gnunet.org/gnunet-testbed-subsystem)
+ *
+ * @{
  */
 
 #ifndef GNUNET_TESTBED_SERVICE_H
@@ -88,7 +95,6 @@ GNUNET_TESTBED_host_create (const char *hostname,
                             uint16_t port);
 
 
-
 /**
  * Create a host to run peers and controllers on.  This function is used
  * if a peer learns about a host via IPC between controllers (and thus
@@ -176,11 +182,10 @@ struct GNUNET_TESTBED_HostHabitableCheckHandle;
  *          given to GNUNET_TESTBED_is_host_habitable() is NULL
  * @param status GNUNET_YES if it is habitable; GNUNET_NO if not
  */
-typedef void (*GNUNET_TESTBED_HostHabitableCallback) (void *cls,
-                                                      const struct
-                                                      GNUNET_TESTBED_Host
-                                                      *host,
-                                                      int status);
+typedef void
+(*GNUNET_TESTBED_HostHabitableCallback) (void *cls,
+                                         const struct GNUNET_TESTBED_Host *host,
+                                         int status);
 
 
 /**
@@ -252,7 +257,6 @@ enum GNUNET_TESTBED_EventType
    * A requested testbed operation has been completed.
    */
   GNUNET_TESTBED_ET_OPERATION_FINISHED = 4,
-
 };
 
 
@@ -261,7 +265,6 @@ enum GNUNET_TESTBED_EventType
  */
 enum GNUNET_TESTBED_PeerInformationType
 {
-
   /**
    * Special value (not valid for requesting information)
    * that is used in the event struct if a 'generic' pointer
@@ -285,7 +288,6 @@ enum GNUNET_TESTBED_PeerInformationType
    * 'GNUNET_TESTNIG_operation_done' is called.
    */
   GNUNET_TESTBED_PIT_IDENTITY
-
 };
 
 
@@ -295,7 +297,6 @@ enum GNUNET_TESTBED_PeerInformationType
  */
 struct GNUNET_TESTBED_EventInformation
 {
-
   /**
    * Type of the event.
    */
@@ -316,7 +317,6 @@ struct GNUNET_TESTBED_EventInformation
    */
   union
   {
-
     /**
      * Details about peer start event.
      */
@@ -332,7 +332,6 @@ struct GNUNET_TESTBED_EventInformation
        * Handle for the peer that was started.
        */
       struct GNUNET_TESTBED_Peer *peer;
-
     } peer_start;
 
     /**
@@ -340,12 +339,10 @@ struct GNUNET_TESTBED_EventInformation
      */
     struct
     {
-
       /**
        * Handle for the peer that was started.
        */
       struct GNUNET_TESTBED_Peer *peer;
-
     } peer_stop;
 
     /**
@@ -362,7 +359,6 @@ struct GNUNET_TESTBED_EventInformation
        * Handle for one of the connected peers.
        */
       struct GNUNET_TESTBED_Peer *peer2;
-
     } peer_connect;
 
     /**
@@ -379,7 +375,6 @@ struct GNUNET_TESTBED_EventInformation
        * Handle for one of the disconnected peers.
        */
       struct GNUNET_TESTBED_Peer *peer2;
-
     } peer_disconnect;
 
     /**
@@ -397,11 +392,8 @@ struct GNUNET_TESTBED_EventInformation
        * (whatever the GNUNET_TESTBED_ConnectAdapter returned).
        */
       void *generic;
-
     } operation_finished;
-
   } details;
-
 };
 
 
@@ -412,8 +404,10 @@ struct GNUNET_TESTBED_EventInformation
  * @param cls closure
  * @param event information about the event
  */
-typedef void (*GNUNET_TESTBED_ControllerCallback)(void *cls,
-                                                  const struct GNUNET_TESTBED_EventInformation *event);
+typedef void
+(*GNUNET_TESTBED_ControllerCallback)(void *cls,
+                                     const struct
+                                     GNUNET_TESTBED_EventInformation *event);
 
 
 /**
@@ -427,17 +421,19 @@ struct GNUNET_TESTBED_ControllerProc;
  *
  * @param cls the closure from GNUNET_TESTBED_controller_start()
  * @param cfg the configuration with which the controller has been started;
- *          NULL if status is not GNUNET_OK
- * @param status GNUNET_OK if the startup is successfull; GNUNET_SYSERR if not,
+ *          NULL if status is not #GNUNET_OK
+ * @param status #GNUNET_OK if the startup is successfull; #GNUNET_SYSERR if not,
  *          GNUNET_TESTBED_controller_stop() shouldn't be called in this case
  */
-typedef void (*GNUNET_TESTBED_ControllerStatusCallback) (void *cls,
-                                                        const struct GNUNET_CONFIGURATION_Handle *cfg,
-                                                        int status);
+typedef void
+(*GNUNET_TESTBED_ControllerStatusCallback) (void *cls,
+                                            const struct
+                                            GNUNET_CONFIGURATION_Handle *cfg,
+                                            int status);
 
 
 /**
- * Starts a controller process at the given host.  The given host's configration
+ * Starts a controller process at the given host.  The given host's configuration
  * is used as a Template configuration to use for the remote controller; the
  * remote controller will be started with a slightly modified configuration
  * (port numbers, unix domain sockets and service home values are changed as per
@@ -480,7 +476,7 @@ GNUNET_TESTBED_controller_stop (struct GNUNET_TESTBED_ControllerProc *cproc);
 
 /**
  * Connect to a controller process.  The configuration to use for the connection
- * is retreived from the given host where a controller is started using
+ * is retrieved from the given host where a controller is started using
  * GNUNET_TESTBED_controller_start().
  *
  * @param host host to run the controller on; This should be the same host if
@@ -524,8 +520,9 @@ struct GNUNET_TESTBED_HostRegistrationHandle;
  * @param cls the closure
  * @param emsg the error message; NULL if host registration is successful
  */
-typedef void (* GNUNET_TESTBED_HostRegistrationCompletion) (void *cls,
-                                                            const char *emsg);
+typedef void
+(*GNUNET_TESTBED_HostRegistrationCompletion) (void *cls,
+                                              const char *emsg);
 
 
 /**
@@ -572,11 +569,11 @@ GNUNET_TESTBED_cancel_registration (struct GNUNET_TESTBED_HostRegistrationHandle
  * @param emsg error message in case the operation has failed; will be NULL if
  *          operation has executed successfully.
  */
-typedef void (*GNUNET_TESTBED_OperationCompletionCallback) (void *cls,
-                                                            struct
-                                                            GNUNET_TESTBED_Operation
-                                                            *op,
-                                                            const char *emsg);
+typedef void
+(*GNUNET_TESTBED_OperationCompletionCallback) (void *cls,
+                                               struct GNUNET_TESTBED_Operation *
+                                               op,
+                                               const char *emsg);
 
 
 /**
@@ -645,9 +642,10 @@ GNUNET_TESTBED_get_slave_config (void *op_cls,
  *          creation
  * @param emsg NULL if peer is not NULL; else MAY contain the error description
  */
-typedef void (*GNUNET_TESTBED_PeerCreateCallback) (void *cls,
-                                                   struct GNUNET_TESTBED_Peer *peer,
-                                                   const char *emsg);
+typedef void
+(*GNUNET_TESTBED_PeerCreateCallback) (void *cls,
+                                      struct GNUNET_TESTBED_Peer *peer,
+                                      const char *emsg);
 
 
 /**
@@ -694,8 +692,9 @@ GNUNET_TESTBED_peer_create (struct GNUNET_TESTBED_Controller *controller,
  * @param cls the closure from GNUNET_TESTBED_peer_start/stop()
  * @param emsg NULL on success; otherwise an error description
  */
-typedef void (*GNUNET_TESTBED_PeerChurnCallback) (void *cls,
-                                                  const char *emsg);
+typedef void
+(*GNUNET_TESTBED_PeerChurnCallback) (void *cls,
+                                     const char *emsg);
 
 
 /**
@@ -773,13 +772,12 @@ struct GNUNET_TESTBED_PeerInformation
  * @param emsg error message if the operation has failed; will be NULL if the
  *          operation is successfull
  */
-typedef void (*GNUNET_TESTBED_PeerInfoCallback) (void *cb_cls,
-                                                 struct GNUNET_TESTBED_Operation
-                                                 *op,
-                                                 const struct
-                                                 GNUNET_TESTBED_PeerInformation
-                                                 *pinfo,
-                                                 const char *emsg);
+typedef void
+(*GNUNET_TESTBED_PeerInfoCallback) (void *cb_cls,
+                                    struct GNUNET_TESTBED_Operation *op,
+                                    const struct
+                                    GNUNET_TESTBED_PeerInformation *pinfo,
+                                    const char *emsg);
 
 
 /**
@@ -814,7 +812,8 @@ GNUNET_TESTBED_peer_get_information (struct GNUNET_TESTBED_Peer *peer,
  */
 struct GNUNET_TESTBED_Operation *
 GNUNET_TESTBED_peer_update_configuration (struct GNUNET_TESTBED_Peer *peer,
-                                          const struct GNUNET_CONFIGURATION_Handle *cfg);
+                                          const struct
+                                          GNUNET_CONFIGURATION_Handle *cfg);
 
 
 /**
@@ -847,7 +846,8 @@ struct GNUNET_TESTBED_Operation *
 GNUNET_TESTBED_peer_manage_service (void *op_cls,
                                     struct GNUNET_TESTBED_Peer *peer,
                                     const char *service_name,
-                                    GNUNET_TESTBED_OperationCompletionCallback cb,
+                                    GNUNET_TESTBED_OperationCompletionCallback
+                                    cb,
                                     void *cb_cls,
                                     unsigned int start);
 
@@ -874,7 +874,6 @@ GNUNET_TESTBED_shutdown_peers (struct GNUNET_TESTBED_Controller *c,
                                void *cb_cls);
 
 
-
 /**
  * Options for peer connections.
  */
@@ -899,7 +898,6 @@ enum GNUNET_TESTBED_ConnectOption
    * particular transports, force simulation of particular latencies
    * or message loss rates, or set bandwidth limitations.
    */
-
 };
 
 
@@ -939,13 +937,13 @@ struct GNUNET_TESTBED_Operation *
 GNUNET_TESTBED_underlay_configure_link (void *op_cls,
                                         struct GNUNET_TESTBED_Peer *p1,
                                         struct GNUNET_TESTBED_Peer *p2,
-                                        enum GNUNET_TESTBED_ConnectOption co, ...);
-
+                                        enum GNUNET_TESTBED_ConnectOption co,
+                                        ...);
 
 
 /**
  * Topologies and topology options supported for testbeds. Options should always
- * end with GNUNET_TESTBED_TOPOLOGY_OPTION_END
+ * end with #GNUNET_TESTBED_TOPOLOGY_OPTION_END
  */
 enum GNUNET_TESTBED_TopologyOption
 {
@@ -972,6 +970,11 @@ enum GNUNET_TESTBED_TopologyOption
    */
   GNUNET_TESTBED_TOPOLOGY_RING,
 
+  /**
+   * Star topology.  No options.
+   */
+  GNUNET_TESTBED_TOPOLOGY_STAR,
+
   /**
    * 2-d torus.  No options.
    */
@@ -1052,8 +1055,11 @@ enum GNUNET_TESTBED_TopologyOption
 struct GNUNET_TESTBED_Operation *
 GNUNET_TESTBED_underlay_configure_topology_va (void *op_cls,
                                                unsigned int num_peers,
-                                               struct GNUNET_TESTBED_Peer **peers,
-                                               enum GNUNET_TESTBED_TopologyOption topo,
+                                               struct GNUNET_TESTBED_Peer **
+                                               peers,
+                                               enum
+                                               GNUNET_TESTBED_TopologyOption
+                                               topo,
                                                va_list ap);
 
 
@@ -1072,7 +1078,8 @@ struct GNUNET_TESTBED_Operation *
 GNUNET_TESTBED_underlay_configure_topology (void *op_cls,
                                             unsigned int num_peers,
                                             struct GNUNET_TESTBED_Peer **peers,
-                                            enum GNUNET_TESTBED_TopologyOption topo,
+                                            enum GNUNET_TESTBED_TopologyOption
+                                            topo,
                                             ...);
 
 
@@ -1108,8 +1115,10 @@ GNUNET_TESTBED_overlay_connect (void *op_cls,
  * @param nfailures the number of overlay connects which failed
  */
 typedef void (*GNUNET_TESTBED_TopologyCompletionCallback) (void *cls,
-                                                          unsigned int nsuccess,
-                                                          unsigned int nfailures);
+                                                           unsigned int
+                                                           nsuccess,
+                                                           unsigned int
+                                                           nfailures);
 
 
 /**
@@ -1140,7 +1149,8 @@ GNUNET_TESTBED_overlay_configure_topology_va (void *op_cls,
                                               GNUNET_TESTBED_TopologyCompletionCallback
                                               comp_cb,
                                               void *comp_cb_cls,
-                                              enum GNUNET_TESTBED_TopologyOption topo,
+                                              enum GNUNET_TESTBED_TopologyOption
+                                              topo,
                                               va_list va);
 
 
@@ -1172,7 +1182,8 @@ GNUNET_TESTBED_overlay_configure_topology (void *op_cls,
                                            GNUNET_TESTBED_TopologyCompletionCallback
                                            comp_cb,
                                            void *comp_cb_cls,
-                                           enum GNUNET_TESTBED_TopologyOption topo,
+                                           enum GNUNET_TESTBED_TopologyOption
+                                           topo,
                                            ...);
 
 
@@ -1187,7 +1198,9 @@ GNUNET_TESTBED_overlay_configure_topology (void *op_cls,
  *        be written to.
  */
 void
-GNUNET_TESTBED_overlay_write_topology_to_file (struct GNUNET_TESTBED_Controller *controller,
+GNUNET_TESTBED_overlay_write_topology_to_file (struct
+                                               GNUNET_TESTBED_Controller *
+                                               controller,
                                                const char *filename);
 
 
@@ -1201,8 +1214,9 @@ GNUNET_TESTBED_overlay_write_topology_to_file (struct GNUNET_TESTBED_Controller
  *          from GNUNET_TESTBED_service_connect()
  * @return service handle to return in 'op_result', NULL on error
  */
-typedef void * (*GNUNET_TESTBED_ConnectAdapter)(void *cls,
-                                                const struct GNUNET_CONFIGURATION_Handle *cfg);
+typedef void *
+(*GNUNET_TESTBED_ConnectAdapter)(void *cls,
+                                 const struct GNUNET_CONFIGURATION_Handle *cfg);
 
 
 /**
@@ -1212,8 +1226,9 @@ typedef void * (*GNUNET_TESTBED_ConnectAdapter)(void *cls,
  * @param cls closure
  * @param op_result service handle returned from the connect adapter
  */
-typedef void (*GNUNET_TESTBED_DisconnectAdapter)(void *cls,
-                                                 void *op_result);
+typedef void
+(*GNUNET_TESTBED_DisconnectAdapter)(void *cls,
+                                    void *op_result);
 
 
 /**
@@ -1225,14 +1240,12 @@ typedef void (*GNUNET_TESTBED_DisconnectAdapter)(void *cls,
  * @param emsg error message in case the operation has failed; will be NULL if
  *          operation has executed successfully.
  */
-typedef void (*GNUNET_TESTBED_ServiceConnectCompletionCallback) (void *cls,
-                                                                 struct
-                                                                 GNUNET_TESTBED_Operation
-                                                                 *op,
-                                                                 void
-                                                                 *ca_result,
-                                                                 const char
-                                                                 *emsg );
+typedef void
+(*GNUNET_TESTBED_ServiceConnectCompletionCallback) (void *cls,
+                                                    struct
+                                                    GNUNET_TESTBED_Operation *op,
+                                                    void *ca_result,
+                                                    const char *emsg);
 
 
 /**
@@ -1261,7 +1274,8 @@ struct GNUNET_TESTBED_Operation *
 GNUNET_TESTBED_service_connect (void *op_cls,
                                 struct GNUNET_TESTBED_Peer *peer,
                                 const char *service_name,
-                                GNUNET_TESTBED_ServiceConnectCompletionCallback cb,
+                                GNUNET_TESTBED_ServiceConnectCompletionCallback
+                                cb,
                                 void *cb_cls,
                                 GNUNET_TESTBED_ConnectAdapter ca,
                                 GNUNET_TESTBED_DisconnectAdapter da,
@@ -1301,15 +1315,16 @@ GNUNET_TESTBED_operation_done (struct GNUNET_TESTBED_Operation *operation);
  * @param subsystem name of subsystem that created the statistic
  * @param name the name of the datum
  * @param value the current value
- * @param is_persistent GNUNET_YES if the value is persistent, GNUNET_NO if not
- * @return GNUNET_OK to continue, GNUNET_SYSERR to abort iteration
+ * @param is_persistent #GNUNET_YES if the value is persistent, #GNUNET_NO if not
+ * @return #GNUNET_OK to continue, #GNUNET_SYSERR to abort iteration
  */
-typedef int (*GNUNET_TESTBED_StatisticsIterator) (void *cls,
-                                                  const struct GNUNET_TESTBED_Peer *peer,
-                                                  const char *subsystem,
-                                                  const char *name,
-                                                  uint64_t value,
-                                                  int is_persistent);
+typedef int
+(*GNUNET_TESTBED_StatisticsIterator) (void *cls,
+                                      const struct GNUNET_TESTBED_Peer *peer,
+                                      const char *subsystem,
+                                      const char *name,
+                                      uint64_t value,
+                                      int is_persistent);
 
 
 /**
@@ -1347,11 +1362,13 @@ GNUNET_TESTBED_get_statistics (unsigned int num_peers,
 uint32_t
 GNUNET_TESTBED_get_index (const struct GNUNET_TESTBED_Peer *peer);
 
+
 /**
  * Handle for testbed run helper funtions
  */
 struct GNUNET_TESTBED_RunHandle;
 
+
 /**
  * Signature of a main function for a testcase.
  *
@@ -1366,12 +1383,13 @@ struct GNUNET_TESTBED_RunHandle;
  *          failed
  * @see GNUNET_TESTBED_test_run()
  */
-typedef void (*GNUNET_TESTBED_TestMaster)(void *cls,
-                                          struct GNUNET_TESTBED_RunHandle *h,
-                                          unsigned int num_peers,
-                                          struct GNUNET_TESTBED_Peer **peers,
-                                          unsigned int links_succeeded,
-                                          unsigned int links_failed);
+typedef void
+(*GNUNET_TESTBED_TestMaster)(void *cls,
+                             struct GNUNET_TESTBED_RunHandle *h,
+                             unsigned int num_peers,
+                             struct GNUNET_TESTBED_Peer **peers,
+                             unsigned int links_succeeded,
+                             unsigned int links_failed);
 
 
 /**
@@ -1447,7 +1465,7 @@ GNUNET_TESTBED_run (const char *host_filename,
  *                   respective 'enum GNUNET_TESTBED_EventType'
  *                   (i.e.  "(1LL << GNUNET_TESTBED_ET_CONNECT) || ...")
  * @param cc controller callback to invoke on events; This callback is called
- *        for all peer start events even if GNUNET_TESTBED_ET_PEER_START isn't
+ *        for all peer start events even if #GNUNET_TESTBED_ET_PEER_START isn't
  *        set in the event_mask as this is the only way get access to the
  *        handle of each peer
  * @param cc_cls closure for @a cc
@@ -1477,6 +1495,7 @@ GNUNET_TESTBED_test_run (const char *testname,
 struct GNUNET_TESTBED_Controller *
 GNUNET_TESTBED_run_get_controller_handle (struct GNUNET_TESTBED_RunHandle *h);
 
+
 /**
  * Opaque handle for barrier
  */
@@ -1502,7 +1521,6 @@ enum GNUNET_TESTBED_BarrierStatus
    * Error status
    */
   GNUNET_TESTBED_BARRIERSTATUS_ERROR,
-
 };
 
 
@@ -1514,17 +1532,19 @@ enum GNUNET_TESTBED_BarrierStatus
  * @param cls the closure given to GNUNET_TESTBED_barrier_init()
  * @param name the name of the barrier
  * @param barrier the barrier handle
- * @param status status of the barrier; GNUNET_OK if the barrier is crossed;
- *   GNUNET_SYSERR upon error
- * @param emsg if the status were to be GNUNET_SYSERR, this parameter has the
+ * @param status status of the barrier.  The barrier is removed once it has been
+ *          crossed or an error occurs while processing it.  Therefore it is
+ *          invalid to call GNUNET_TESTBED_barrier_cancel() on a crossed or
+ *          errored barrier.
+ * @param emsg if the status were to be #GNUNET_SYSERR, this parameter has the
  *   error messsage
  */
-typedef void (*GNUNET_TESTBED_barrier_status_cb) (void *cls,
-                                                  const char *name,
-                                                  struct GNUNET_TESTBED_Barrier
-                                                  *barrier,
-                                                  enum GNUNET_TESTBED_BarrierStatus status,
-                                                  const char *emsg);
+typedef void
+(*GNUNET_TESTBED_barrier_status_cb) (void *cls,
+                                     const char *name,
+                                     struct GNUNET_TESTBED_Barrier *barrier,
+                                     enum GNUNET_TESTBED_BarrierStatus status,
+                                     const char *emsg);
 
 
 /**
@@ -1538,14 +1558,15 @@ typedef void (*GNUNET_TESTBED_barrier_status_cb) (void *cls,
  *   GNUNET_TESTBED_barrier_reached().
  * @param cb the callback to call when the barrier is reached or upon error.
  *   Cannot be NULL.
- * @param cls closure for the above callback
+ * @param cb_cls closure for @a cb
  * @return barrier handle
  */
 struct GNUNET_TESTBED_Barrier *
 GNUNET_TESTBED_barrier_init (struct GNUNET_TESTBED_Controller *controller,
                              const char *name,
                              unsigned int quorum,
-                             GNUNET_TESTBED_barrier_status_cb cb, void *cls);
+                             GNUNET_TESTBED_barrier_status_cb cb,
+                             void *cb_cls);
 
 
 /**
@@ -1570,12 +1591,13 @@ struct GNUNET_TESTBED_BarrierWaitHandle;
  *
  * @param cls closure pointer given to GNUNET_TESTBED_barrier_wait()
  * @param name the barrier name
- * @param status GNUNET_SYSERR in case of error while waiting for the barrier;
- *   GNUNET_OK if the barrier is crossed
+ * @param status #GNUNET_SYSERR in case of error while waiting for the barrier;
+ *   #GNUNET_OK if the barrier is crossed
  */
-typedef void (*GNUNET_TESTBED_barrier_wait_cb) (void *cls,
-                                                const char *name,
-                                                int status);
+typedef void
+(*GNUNET_TESTBED_barrier_wait_cb) (void *cls,
+                                   const char *name,
+                                   int status);
 
 
 /**
@@ -1645,7 +1667,9 @@ enum GNUNET_TESTBED_UnderlayLinkModelType
  */
 struct GNUNET_TESTBED_UnderlayLinkModel *
 GNUNET_TESTBED_underlaylinkmodel_create (struct GNUNET_TESTBED_Peer *peer,
-                                         enum GNUNET_TESTBED_UnderlayLinkModelType type);
+                                         enum
+                                         GNUNET_TESTBED_UnderlayLinkModelType
+                                         type);
 
 
 /**
@@ -1658,7 +1682,9 @@ GNUNET_TESTBED_underlaylinkmodel_create (struct GNUNET_TESTBED_Peer *peer,
  * @param peer the peer to add
  */
 void
-GNUNET_TESTBED_underlaylinkmodel_add_peer (struct GNUNET_TESTBED_UnderlayLinkModel *model,
+GNUNET_TESTBED_underlaylinkmodel_add_peer (struct
+                                           GNUNET_TESTBED_UnderlayLinkModel *
+                                           model,
                                            struct GNUNET_TESTBED_Peer *peer);
 
 
@@ -1674,7 +1700,9 @@ GNUNET_TESTBED_underlaylinkmodel_add_peer (struct GNUNET_TESTBED_UnderlayLinkMod
  * @param bandwidth bandwidth of the link in kilobytes per second [kB/s]
  */
 void
-GNUNET_TESTBED_underlaylinkmodel_set_link (struct GNUNET_TESTBED_UnderlayLinkModel *model,
+GNUNET_TESTBED_underlaylinkmodel_set_link (struct
+                                           GNUNET_TESTBED_UnderlayLinkModel *
+                                           model,
                                            struct GNUNET_TESTBED_Peer *peer,
                                            uint32_t latency,
                                            uint32_t loss,
@@ -1688,7 +1716,8 @@ GNUNET_TESTBED_underlaylinkmodel_set_link (struct GNUNET_TESTBED_UnderlayLinkMod
  * @param model the model to commit
  */
 void
-GNUNET_TESTBED_underlaylinkmodel_commit (struct GNUNET_TESTBED_UnderlayLinkModel *model);
+GNUNET_TESTBED_underlaylinkmodel_commit (struct
+                                         GNUNET_TESTBED_UnderlayLinkModel *model);
 
 
 /**
@@ -1700,7 +1729,8 @@ GNUNET_TESTBED_underlaylinkmodel_commit (struct GNUNET_TESTBED_UnderlayLinkModel
  * @param model the model to unallocate
  */
 void
-GNUNET_TESTBED_underlaylinkmodel_free (struct GNUNET_TESTBED_UnderlayLinkModel *model);
+GNUNET_TESTBED_underlaylinkmodel_free (struct
+                                       GNUNET_TESTBED_UnderlayLinkModel *model);
 
 
 #if 0                           /* keep Emacsens' auto-indent happy */
@@ -1713,3 +1743,5 @@ GNUNET_TESTBED_underlaylinkmodel_free (struct GNUNET_TESTBED_UnderlayLinkModel *
 #endif
 
 #endif
+
+/** @} */  /* end of group */
