@@ -1317,7 +1317,7 @@ main (int argc,
                              NULL))
         ? 0
         : 1;
-  GNUNET_free ((void *) argv);
+  GNUNET_free_nz ((void *) argv);
   return ret;
 }
 
