@@ -44,6 +44,16 @@ const struct GNUNET_CONFIGURATION_Handle *cfg;
 
 struct RequestHandle
 {
+  /**
+   * DLL
+   */
+  struct RequestHandle *next;
+
+  /**
+   * DLL
+   */
+  struct RequestHandle *prev;
+
   /**
    * Handle to rest request
    */
@@ -70,6 +80,17 @@ struct RequestHandle
   char *url;
 };
 
+/**
+ * DLL
+ */
+static struct RequestHandle *requests_head;
+
+/**
+ * DLL
+ */
+static struct RequestHandle *requests_tail;
+
+
 
 /**
  * Cleanup request handle.
@@ -82,6 +103,9 @@ cleanup_handle (struct RequestHandle *handle)
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Cleaning up\n");
   if (NULL != handle->url)
     GNUNET_free (handle->url);
+  GNUNET_CONTAINER_DLL_remove (requests_head,
+                               requests_tail,
+                               handle);
   GNUNET_free (handle);
 }
 
@@ -347,7 +371,7 @@ options_cont (struct GNUNET_REST_RequestHandle *con_handle,
  * @param proc_cls closure for @a proc
  * @return #GNUNET_OK if request accepted
  */
-static void
+static enum GNUNET_GenericReturnValue
 rest_config_process_request (struct GNUNET_REST_RequestHandle *conndata_handle,
                              GNUNET_REST_ResultProcessor proc,
                              void *proc_cls)
@@ -367,13 +391,16 @@ rest_config_process_request (struct GNUNET_REST_RequestHandle *conndata_handle,
   handle->url = GNUNET_strdup (conndata_handle->url);
   if (handle->url[strlen (handle->url) - 1] == '/')
     handle->url[strlen (handle->url) - 1] = '\0';
-
+  GNUNET_CONTAINER_DLL_insert (requests_head,
+                               requests_tail,
+                               handle);
   if (GNUNET_NO ==
       GNUNET_REST_handle_request (conndata_handle, handlers, &err, handle))
   {
-    handle->response_code = err.error_code;
-    GNUNET_SCHEDULER_add_now (&do_error, handle);
+    cleanup_handle (handle);
+    return GNUNET_NO;
   }
+  return GNUNET_YES;
 }
 
 
@@ -391,15 +418,13 @@ libgnunet_plugin_rest_config_init (void *cls)
   cfg = cls;
   struct GNUNET_REST_Plugin *api;
 
-  if (NULL != plugin.cfg)
-    return NULL; /* can only initialize once! */
   memset (&plugin, 0, sizeof(struct Plugin));
   plugin.cfg = cfg;
   api = GNUNET_new (struct GNUNET_REST_Plugin);
   api->cls = &plugin;
   api->name = GNUNET_REST_API_NS_CONFIG;
   api->process_request = &rest_config_process_request;
-  GNUNET_log (GNUNET_ERROR_TYPE_INFO, _ ("CONFIG REST API initialized\n"));
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO, _("CONFIG REST API initialized\n"));
   return api;
 }
 
@@ -414,8 +439,11 @@ void *
 libgnunet_plugin_rest_config_done (void *cls)
 {
   struct GNUNET_REST_Plugin *api = cls;
-  struct Plugin *plugin = api->cls;
+  struct Plugin *plugin;
 
+  while (NULL != requests_head)
+    cleanup_handle (requests_head);
+  plugin = api->cls;
   plugin->cfg = NULL;
   GNUNET_free (api);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "CONFIG REST plugin is finished\n");
