@@ -100,7 +100,7 @@ struct CustomLogger
  * Asynchronous scope of the current thread, or NULL if we have not
  * entered an async scope yet.
  */
-static __thread struct GNUNET_AsyncScopeSave current_async_scope;
+static GNUNET_THREAD_LOCAL struct GNUNET_AsyncScopeSave current_async_scope;
 
 /**
  * The last "bulk" error message that we have been logging.
@@ -287,14 +287,13 @@ GNUNET_abort_ ()
  * Utility function - reallocates logdefs array to be twice as large.
  */
 static void
-resize_logdefs ()
+resize_logdefs (void)
 {
   logdefs_size = (logdefs_size + 1) * 2;
   logdefs = GNUNET_realloc (logdefs, logdefs_size * sizeof(struct LogDef));
 }
 
 
-#if ! TALER_WALLET_ONLY
 /**
  * Rotate logs, deleting the oldest log.
  *
@@ -403,9 +402,6 @@ setup_log_file (const struct tm *tm)
 }
 
 
-#endif
-
-
 /**
  * Utility function - adds a parsed definition to logdefs array.
  *
@@ -709,7 +705,9 @@ parse_all_definitions ()
  * @return #GNUNET_OK on success
  */
 int
-GNUNET_log_setup (const char *comp, const char *loglevel, const char *logfile)
+GNUNET_log_setup (const char *comp,
+                  const char *loglevel,
+                  const char *logfile)
 {
   const char *env_logfile;
 
@@ -717,9 +715,9 @@ GNUNET_log_setup (const char *comp, const char *loglevel, const char *logfile)
 #if ! defined(GNUNET_CULL_LOGGING)
   parse_all_definitions ();
 #endif
-  GNUNET_free_non_null (component);
+  GNUNET_free (component);
   GNUNET_asprintf (&component, "%s-%d", comp, getpid ());
-  GNUNET_free_non_null (component_nopid);
+  GNUNET_free (component_nopid);
   component_nopid = GNUNET_strdup (comp);
 
   env_logfile = getenv ("GNUNET_FORCE_LOGFILE");
@@ -727,11 +725,11 @@ GNUNET_log_setup (const char *comp, const char *loglevel, const char *logfile)
     logfile = env_logfile;
   if (NULL == logfile)
     return GNUNET_OK;
-  GNUNET_free_non_null (log_file_name);
+  GNUNET_free (log_file_name);
   log_file_name = GNUNET_STRINGS_filename_expand (logfile);
   if (NULL == log_file_name)
     return GNUNET_SYSERR;
-#if TALER_WALLET_ONLY || defined(GNUNET_CULL_LOGGING)
+#if defined(GNUNET_CULL_LOGGING)
   /* log file option not allowed for wallet logic */
   GNUNET_assert (NULL == logfile);
   return GNUNET_OK;
@@ -1023,7 +1021,7 @@ mylog (enum GNUNET_ErrorType kind,
     }
 
     vsnprintf (buf, size, message, va);
-#if ! (defined(GNUNET_CULL_LOGGING) || TALER_WALLET_ONLY)
+#if ! defined(GNUNET_CULL_LOGGING)
     if (NULL != tmptr)
       (void) setup_log_file (tmptr);
 #endif
@@ -1150,7 +1148,7 @@ GNUNET_h2s (const struct GNUNET_HashCode *hc)
 const char *
 GNUNET_h2s2 (const struct GNUNET_HashCode *hc)
 {
-  static struct GNUNET_CRYPTO_HashAsciiEncoded ret;
+  static GNUNET_THREAD_LOCAL struct GNUNET_CRYPTO_HashAsciiEncoded ret;
 
   GNUNET_CRYPTO_hash_to_enc (hc, &ret);
   ret.encoding[8] = '\0';
@@ -1170,7 +1168,7 @@ GNUNET_h2s2 (const struct GNUNET_HashCode *hc)
 const char *
 GNUNET_p2s (const struct GNUNET_CRYPTO_EddsaPublicKey *p)
 {
-  static struct GNUNET_CRYPTO_HashAsciiEncoded ret;
+  static GNUNET_THREAD_LOCAL struct GNUNET_CRYPTO_HashAsciiEncoded ret;
   struct GNUNET_HashCode hc;
 
   GNUNET_CRYPTO_hash (p, sizeof(*p), &hc);
@@ -1192,7 +1190,7 @@ GNUNET_p2s (const struct GNUNET_CRYPTO_EddsaPublicKey *p)
 const char *
 GNUNET_p2s2 (const struct GNUNET_CRYPTO_EddsaPublicKey *p)
 {
-  static struct GNUNET_CRYPTO_HashAsciiEncoded ret;
+  static GNUNET_THREAD_LOCAL struct GNUNET_CRYPTO_HashAsciiEncoded ret;
   struct GNUNET_HashCode hc;
 
   GNUNET_CRYPTO_hash (p, sizeof(*p), &hc);
@@ -1214,7 +1212,7 @@ GNUNET_p2s2 (const struct GNUNET_CRYPTO_EddsaPublicKey *p)
 const char *
 GNUNET_e2s (const struct GNUNET_CRYPTO_EcdhePublicKey *p)
 {
-  static struct GNUNET_CRYPTO_HashAsciiEncoded ret;
+  static GNUNET_THREAD_LOCAL struct GNUNET_CRYPTO_HashAsciiEncoded ret;
   struct GNUNET_HashCode hc;
 
   GNUNET_CRYPTO_hash (p, sizeof(*p), &hc);
@@ -1236,7 +1234,7 @@ GNUNET_e2s (const struct GNUNET_CRYPTO_EcdhePublicKey *p)
 const char *
 GNUNET_e2s2 (const struct GNUNET_CRYPTO_EcdhePublicKey *p)
 {
-  static struct GNUNET_CRYPTO_HashAsciiEncoded ret;
+  static GNUNET_THREAD_LOCAL struct GNUNET_CRYPTO_HashAsciiEncoded ret;
   struct GNUNET_HashCode hc;
 
   GNUNET_CRYPTO_hash (p, sizeof(*p), &hc);
@@ -1258,7 +1256,7 @@ GNUNET_e2s2 (const struct GNUNET_CRYPTO_EcdhePublicKey *p)
 const char *
 GNUNET_sh2s (const struct GNUNET_ShortHashCode *shc)
 {
-  static char buf[64];
+  static GNUNET_THREAD_LOCAL char buf[64];
 
   GNUNET_STRINGS_data_to_string (shc, sizeof(*shc), buf, sizeof(buf));
   buf[6] = '\0';
@@ -1278,7 +1276,7 @@ GNUNET_sh2s (const struct GNUNET_ShortHashCode *shc)
 const char *
 GNUNET_uuid2s (const struct GNUNET_Uuid *uuid)
 {
-  static char buf[32];
+  static GNUNET_THREAD_LOCAL char buf[32];
 
   GNUNET_STRINGS_data_to_string (uuid, sizeof(*uuid), buf, sizeof(buf));
   buf[6] = '\0';
@@ -1297,7 +1295,7 @@ GNUNET_uuid2s (const struct GNUNET_Uuid *uuid)
 const char *
 GNUNET_h2s_full (const struct GNUNET_HashCode *hc)
 {
-  static struct GNUNET_CRYPTO_HashAsciiEncoded ret;
+  static GNUNET_THREAD_LOCAL struct GNUNET_CRYPTO_HashAsciiEncoded ret;
 
   GNUNET_CRYPTO_hash_to_enc (hc, &ret);
   ret.encoding[sizeof(ret) - 1] = '\0';
@@ -1388,9 +1386,9 @@ GNUNET_a2s (const struct sockaddr *addr, socklen_t addrlen)
 #define LEN                           \
   GNUNET_MAX ((INET6_ADDRSTRLEN + 8), \
               (1 + sizeof(struct sockaddr_un) - sizeof(sa_family_t)))
-  static char buf[LEN];
+  static GNUNET_THREAD_LOCAL char buf[LEN];
 #undef LEN
-  static char b2[6];
+  static GNUNET_THREAD_LOCAL char b2[6];
   const struct sockaddr_in *v4;
   const struct sockaddr_un *un;
   const struct sockaddr_in6 *v6;
